@@ -1,7 +1,7 @@
 # user-visible function to extract the fit measures
 # output can be 1) vector (default), 2) list, 3) matrix, or 4) text
 # in the latter case, the result will be of class "lavaan.fitMeasures"
-# for which the printing is done by print.lavaan.fitMeasures()
+# for which the printing is done by lav_fitmeasures_print()
 
 # new in 0.6-13:
 # the big families are computed in dedicated functions:
@@ -27,6 +27,15 @@ setMethod(
              cat.check.pd = TRUE
            ),
            output = "vector", ...) {
+    dotdotdot <- list(...)
+    if (length(dotdotdot) > 0L) {
+      for (j in seq_along(dotdotdot)) {
+        lav_msg_warn(gettextf(
+          "Unknown argument %s for %s", sQuote(names(dotdotdot)[j]),
+          sQuote("fitMeasures"))
+        )
+      }
+    }
     # note: the ... is not used by lavaan
     lav_fit_measures(
       object = object, fit.measures = fit.measures,
@@ -49,6 +58,15 @@ setMethod(
              cat.check.pd = TRUE
            ),
            output = "vector", ...) {
+    dotdotdot <- list(...)
+    if (length(dotdotdot) > 0L) {
+      for (j in seq_along(dotdotdot)) {
+        lav_msg_warn(gettextf(
+          "Unknown argument %s for %s", sQuote(names(dotdotdot)[j]),
+          sQuote("fitmeasures"))
+        )
+      }
+    }
     # note: the ... is not used by lavaan
     lav_fit_measures(
       object = object, fit.measures = fit.measures,
@@ -59,7 +77,7 @@ setMethod(
 )
 
 # S3 method for efaList
-fitMeasures.efaList <- fitmeasures.efaList <- function(
+lav_efalist_fitmeasures <- function(
     object,
     fit.measures = "all",
     baseline.model = NULL, h1.model = NULL,
@@ -125,6 +143,9 @@ lav_fit_measures <- function(object, fit.measures = "all",
                                cat.check.pd = TRUE
                              ),
                              output = "vector") {
+  # check object
+  object <- lav_object_check_version(object)
+
   # default fm.args
   default.fm.args <- list(
     standard.test = "default",
@@ -143,14 +164,22 @@ lav_fit_measures <- function(object, fit.measures = "all",
 
   # standard test
   if (fm.args$standard.test == "default") {
-    fm.args$standard.test <- object@Options$scaled.test
+    fm.args$standard.test <- object@Options$standard.test
     # usually "standard", but could have been changed
-    # the 'scaled' version will be based on the scaled.test!
     if (is.null(fm.args$standard.test)) { # <older objects
       fm.args$standard.test <- "standard"
     }
   }
 
+  # scaled test
+  if (fm.args$scaled.test == "default") {
+    fm.args$scaled.test <- object@Options$scaled.test
+    # usually "standard", but could have been changed
+    if (is.null(fm.args$scaled.test)) { # <older objects
+      fm.args$scaled.test <- "standard"
+    }
+  }
+
   # do we have data? (yep, we had to include this check)
   if (object@Data@data.type == "none") {
     lav_msg_stop(gettext("fit measures not available if there is no data."))
@@ -292,8 +321,8 @@ lav_fit_measures <- function(object, fit.measures = "all",
     X2.scaled <- TEST[[scaled.idx]]$stat
     df.scaled <- TEST[[scaled.idx]]$df
   }
-  npar <- lav_utils_get_npar(lavobject = object)
-  N <- lav_utils_get_ntotal(lavobject = object) # N vs N-1
+  npar <- lav_object_inspect_npar(object = object, ceq = TRUE)
+  N <- lav_object_inspect_ntotal(object = object) # N vs N-1
 
 
   # define 'sets' of fit measures:
@@ -419,7 +448,7 @@ lav_fit_measures <- function(object, fit.measures = "all",
   }
 
   # lower case
-  fit.measures <- tolower(fit.measures)
+  fit.measures <- fit.measures.orig <- tolower(fit.measures)
 
   # select 'default' fit measures
   if (length(fit.measures) == 1L) {
@@ -482,6 +511,7 @@ lav_fit_measures <- function(object, fit.measures = "all",
 
   # BASELINE FAMILY
   if (any(fit.cfi %in% fit.measures)) {
+
     # rerun baseline?
     if (rerun.lavtest.flag) {
       object@Options$test <- this.test
@@ -634,11 +664,27 @@ lav_fit_measures <- function(object, fit.measures = "all",
     class(out) <- c("lavaan.fitMeasures", "lavaan.vector", "numeric")
   }
 
+  # attributes?
+  # only if fit.measures == "all" or "default"
+  if (length(fit.measures.orig) == 1L &&
+      fit.measures.orig %in% c("all", "default")) {
+    X2.label <- TEST[[test.idx]]$label # NULL if "standard"
+    X2.baseline.label <- object@baseline$test[[test.idx]]$label
+    attr(out, "X2.label") <- X2.label
+    attr(out, "X2.baseline.label") <- X2.baseline.label
+    if (standard.test != "standard") {
+      attr(out, "standard.test") <- standard.test
+    }
+    if (scaled.flag && scaled.test != "standard") {
+      attr(out, "scaled.test") <- scaled.test
+    }
+  }
+
   out
 }
 
 # print a nice summary of the fit measures
-print.lavaan.fitMeasures <- function(x, ..., nd = 3L, add.h0 = TRUE) {
+lav_fitmeasures_print <- function(x, ..., nd = 3L, add.h0 = TRUE) {
   names.x <- names(x)
 
   # scaled?
@@ -661,6 +707,13 @@ print.lavaan.fitMeasures <- function(x, ..., nd = 3L, add.h0 = TRUE) {
       c3 <- c("Scaled", c3)
     }
 
+    # if test is not standard, add label
+    if (!is.null(attr(x, "X2.label"))) {
+      c1 <- c(c1, attr(x, "X2.label"))
+      c2 <- c(c2, "")
+      c3 <- c(c3, "")
+    }
+
     c1 <- c(c1, "Test statistic")
     c2 <- c(c2, sprintf(num.format, x["chisq"]))
     c3 <- c(c3, ifelse(scaled.flag,
@@ -748,11 +801,24 @@ print.lavaan.fitMeasures <- function(x, ..., nd = 3L, add.h0 = TRUE) {
     write.table(M, row.names = TRUE, col.names = FALSE, quote = FALSE)
   }
 
+  # print information about standard.test? (new in 0.6-21)
+  # (only if "standard.test" is not "standard")
+  if (!is.null(attr(x, "standard.test"))) {
+    cat("\nNote: fit measures based on the chi-square test statistic\n",
+           "     use", attr(x, "X2.label"),"\n")
+  }
+
   # independence model
   if ("baseline.chisq" %in% names.x) {
     cat("\nModel Test Baseline Model:\n\n")
 
     c1 <- c2 <- c3 <- character(0L)
+    # if test is not standard, add label
+    if (!is.null(attr(x, "X2.baseline.label"))) {
+      c1 <- c(c1, attr(x, "X2.label"))
+      c2 <- c(c2, "")
+      c3 <- c(c3, "")
+    }
 
     c1 <- c(c1, "Test statistic")
     c2 <- c(c2, sprintf(num.format, x["baseline.chisq"]))
