@@ -2,7 +2,7 @@
 # plot commands
 
 # suggested by JEB
-pairs.lavaan <- function(x, group = 1L, ...) {
+lav_lavaan_pairs <- function(x, group = 1L, ...) {
   X <- x@Data@X[[group]]
   colnames(X) <- x@Data@ov.names[[group]]
   pairs(X, ...)
