@@ -312,7 +312,7 @@ lav_model_estimate <- function(lavmodel = NULL,
     x <- x / parscale
 
     # update GLIST (change `state') and make a COPY!
-    GLIST <- lav_model_x2GLIST(lavmodel, x = x)
+    GLIST <- lav_model_x2glist(lavmodel, x = x)
 
     fx <- lav_model_objective(
       lavmodel = lavmodel,
@@ -380,7 +380,7 @@ lav_model_estimate <- function(lavmodel = NULL,
     x <- x / parscale
 
     # update GLIST (change `state') and make a COPY!
-    GLIST <- lav_model_x2GLIST(lavmodel, x = x)
+    GLIST <- lav_model_x2glist(lavmodel, x = x)
 
     dx <- lav_model_gradient(
       lavmodel = lavmodel,
@@ -487,7 +487,7 @@ lav_model_estimate <- function(lavmodel = NULL,
   # check if the initial values produce a positive definite Sigma
   # to begin with -- but only for estimator="ML"
   if (estimator %in% c("ML", "FML", "MML")) {
-    Sigma.hat <- computeSigmaHat(lavmodel, extra = TRUE)
+    Sigma.hat <- lav_model_sigma(lavmodel, extra = TRUE)
     for (g in 1:ngroups) {
       if (!attr(Sigma.hat[[g]], "po")) {
         group.txt <-
@@ -503,7 +503,7 @@ lav_model_estimate <- function(lavmodel = NULL,
         attr(fx, "fx.group") <- rep(as.numeric(NA), ngroups)
         attr(x, "converged") <- FALSE
         attr(x, "iterations") <- 0L
-        attr(x, "control") <- lavoptions@control
+        attr(x, "control") <- lavoptions$control
         attr(x, "fx") <- fx
         return(x)
       }
@@ -893,7 +893,7 @@ lav_model_estimate <- function(lavmodel = NULL,
     # if inequality constraints, add con.jac/lambda
     # needed for df!
     if (length(lavmodel@ceq.nonlinear.idx) == 0L &&
-        (lavmodel@cin.simple.only || 
+        (lavmodel@cin.simple.only ||
          (length(lavmodel@cin.linear.idx) == 0L &&
           length(lavmodel@cin.nonlinear.idx) == 0L))) {
       optim.out <- list()
@@ -1003,7 +1003,7 @@ lav_model_estimate <- function(lavmodel = NULL,
     attr(JAC, "cin.idx") <- seq_len(nrow(cin.JAC))
     attr(JAC, "ceq.idx") <- nrow(cin.JAC) + seq_len(nrow(ceq.JAC))
     lambda <- c(cin.lambda, ceq.lambda)
-    
+
     optim.out$con.jac <- JAC
     optim.out$lambda <- lambda
   }
