@@ -37,15 +37,7 @@ lav_model_h1_information <- function(lavobject = NULL,
     lavsamplestats <- lavobject@SampleStats
     lavdata <- lavobject@Data
     lavimplied <- lavobject@implied
-    if (.hasSlot(lavobject, "h1")) {
-      lavh1 <- lavobject@h1
-    } else {
-      lavh1 <- lav_h1_implied_logl(
-        lavdata = lavobject@Data,
-        lavsamplestats = lavobject@SampleStats,
-        lavoptions = lavobject@Options
-      )
-    }
+    lavh1 <- lavobject@h1
     lavcache <- lavobject@Cache
     lavoptions <- lavobject@Options
   }
@@ -109,15 +101,7 @@ lav_model_h1_information_expected <- function(lavobject = NULL,
     lavsamplestats <- lavobject@SampleStats
     lavdata <- lavobject@Data
     lavimplied <- lavobject@implied
-    if (.hasSlot(lavobject, "h1")) {
-      lavh1 <- lavobject@h1
-    } else {
-      lavh1 <- lav_h1_implied_logl(
-        lavdata = lavobject@Data,
-        lavsamplestats = lavobject@SampleStats,
-        lavoptions = lavobject@Options
-      )
-    }
+    lavh1 <- lavobject@h1
     lavcache <- lavobject@Cache
     lavoptions <- lavobject@Options
   }
@@ -191,11 +175,7 @@ lav_model_h1_information_expected <- function(lavobject = NULL,
     }
 
     for (g in 1:lavsamplestats@ngroups) {
-      if (.hasSlot(lavdata, "weights")) {
-        WT <- lavdata@weights[[g]]
-      } else {
-        WT <- NULL
-      }
+      WT <- lavdata@weights[[g]]
 
       if (lavsamplestats@missing.flag) {
         # mvnorm
@@ -204,7 +184,8 @@ lav_model_h1_information_expected <- function(lavobject = NULL,
         if (lavmodel@meanstructure && structured) {
           MEAN <- lavimplied$mean[[g]]
         } else {
-          MEAN <- lavsamplestats@missing.h1[[g]]$mu
+          #MEAN <- lavsamplestats@missing.h1[[g]]$mu
+          MEAN <- lavh1$implied$mean[[g]]
         }
 
         if (structured) {
@@ -226,7 +207,8 @@ lav_model_h1_information_expected <- function(lavobject = NULL,
               wt = WT,
               Mu = MEAN,
               # meanstructure = lavmodel@meanstructure,
-              Sigma = lavsamplestats@missing.h1[[g]]$sigma,
+              #Sigma = lavsamplestats@missing.h1[[g]]$sigma,
+              Sigma = lavh1$implied$cov[[g]],
               x.idx = lavsamplestats@x.idx[[g]]
             )
         }
@@ -273,10 +255,7 @@ lav_model_h1_information_expected <- function(lavobject = NULL,
             MEAN <- lavsamplestats@mean[[g]]
           }
 
-          correlation.flag <- FALSE
-          if (.hasSlot(lavmodel, "correlation")) {
-            correlation.flag <- lavmodel@correlation
-          }
+          correlation.flag <- lavmodel@correlation
 
           if (structured) {
             A1[[g]] <- lav_mvnorm_information_expected(
@@ -358,15 +337,7 @@ lav_model_h1_information_observed <- function(lavobject = NULL,
     lavsamplestats <- lavobject@SampleStats
     lavdata <- lavobject@Data
     lavimplied <- lavobject@implied
-    if (.hasSlot(lavobject, "h1")) {
-      lavh1 <- lavobject@h1
-    } else {
-      lavh1 <- lav_h1_implied_logl(
-        lavdata = lavobject@Data,
-        lavsamplestats = lavobject@SampleStats,
-        lavoptions = lavobject@Options
-      )
-    }
+    lavh1 <- lavobject@h1
     lavcache <- lavobject@Cache
     lavoptions <- lavobject@Options
   }
@@ -447,7 +418,8 @@ lav_model_h1_information_observed <- function(lavobject = NULL,
         if (lavmodel@meanstructure && structured) {
           MEAN <- lavimplied$mean[[g]]
         } else {
-          MEAN <- lavsamplestats@missing.h1[[g]]$mu
+          #MEAN <- lavsamplestats@missing.h1[[g]]$mu
+          MEAN <- lavh1$implied$mean[[g]]
         }
 
         if (structured) {
@@ -467,7 +439,8 @@ lav_model_h1_information_observed <- function(lavobject = NULL,
               # wt not needed
               Mu = MEAN,
               # meanstructure = lavmodel@meanstructure,
-              Sigma = lavsamplestats@missing.h1[[g]]$sigma,
+              #Sigma = lavsamplestats@missing.h1[[g]]$sigma,
+              Sigma = lavh1$implied$cov[[g]],
               x.idx = lavsamplestats@x.idx[[g]]
             )
         }
@@ -617,15 +590,7 @@ lav_model_h1_information_firstorder <- function(lavobject = NULL,
     lavsamplestats <- lavobject@SampleStats
     lavdata <- lavobject@Data
     lavimplied <- lavobject@implied
-    if (.hasSlot(lavobject, "h1")) {
-      lavh1 <- lavobject@h1
-    } else {
-      lavh1 <- lav_h1_implied_logl(
-        lavdata = lavobject@Data,
-        lavsamplestats = lavobject@SampleStats,
-        lavoptions = lavobject@Options
-      )
-    }
+    lavh1 <- lavobject@h1
     lavcache <- lavobject@Cache
     lavoptions <- lavobject@Options
   }
@@ -699,11 +664,7 @@ lav_model_h1_information_firstorder <- function(lavobject = NULL,
 
   B1 <- vector("list", length = lavsamplestats@ngroups)
   for (g in 1:lavdata@ngroups) {
-    if (.hasSlot(lavdata, "weights")) {
-      WT <- lavdata@weights[[g]]
-    } else {
-      WT <- NULL
-    }
+    WT <- lavdata@weights[[g]]
 
     if (estimator == "PML") {
       # slow approach: compute outer product of case-wise scores
@@ -721,7 +682,7 @@ lav_model_h1_information_firstorder <- function(lavobject = NULL,
         PI <- NULL
         EXO <- NULL
       }
-      SC <- pml_deriv1(
+      SC <- lav_pml_dploglik_dimplied(
         Sigma.hat = SIGMA,
         Mu.hat = MU,
         TH = TH,
@@ -842,7 +803,8 @@ lav_model_h1_information_firstorder <- function(lavobject = NULL,
         if (lavmodel@meanstructure && structured) {
           MEAN <- lavimplied$mean[[g]]
         } else {
-          MEAN <- lavsamplestats@missing.h1[[g]]$mu
+          #MEAN <- lavsamplestats@missing.h1[[g]]$mu
+          MEAN <- lavh1$implied$mean[[g]]
         }
 
         B1[[g]] <- lav_mvnorm_missing_information_firstorder(
@@ -946,15 +908,7 @@ lav_model_h1_acov <- function(lavobject = NULL,
     lavsamplestats <- lavobject@SampleStats
     lavdata <- lavobject@Data
     lavimplied <- lavobject@implied
-    if (.hasSlot(lavobject, "h1")) {
-      lavh1 <- lavobject@h1
-    } else {
-      lavh1 <- lav_h1_implied_logl(
-        lavdata = lavobject@Data,
-        lavsamplestats = lavobject@SampleStats,
-        lavoptions = lavobject@Options
-      )
-    }
+    lavh1 <- lavobject@h1
     lavcache <- lavobject@Cache
     lavoptions <- lavobject@Options
   }
