@@ -16,7 +16,8 @@ lav_model_hessian <- function(lavmodel = NULL,
       lavmodel2 <- lav_model_set_parameters(lavmodel, x = x)
       lav_model_objective(
         lavmodel = lavmodel2,
-        lavsamplestats = lavsamplestats, lavdata = lavdata
+        lavsamplestats = lavsamplestats, lavdata = lavdata,
+        lavcache = lavcache
       )[1]
     }
     x <- lav_model_get_parameters(lavmodel = lavmodel)
@@ -25,8 +26,7 @@ lav_model_hessian <- function(lavmodel = NULL,
   }
 
   # computing the Richardson extrapolation
-  if (!ceq.simple && .hasSlot(lavmodel, "ceq.simple.only") &&
-    lavmodel@ceq.simple.only) {
+  if (!ceq.simple && lavmodel@ceq.simple.only) {
     npar <- lavmodel@nx.unco
     type.glist <- "unco"
   } else {
@@ -35,8 +35,7 @@ lav_model_hessian <- function(lavmodel = NULL,
   }
   Hessian <- matrix(0, npar, npar)
   x <- lav_model_get_parameters(lavmodel = lavmodel)
-  if (!ceq.simple && .hasSlot(lavmodel, "ceq.simple.only") &&
-    lavmodel@ceq.simple.only) {
+  if (!ceq.simple && lavmodel@ceq.simple.only) {
     # unpack
     x <- drop(x %*% t(lavmodel@ceq.simple.K))
   }
@@ -52,7 +51,7 @@ lav_model_hessian <- function(lavmodel = NULL,
     g.left <-
       lav_model_gradient(
         lavmodel = lavmodel,
-        GLIST = lav_model_x2GLIST(
+        GLIST = lav_model_x2glist(
           lavmodel =
             lavmodel, type = type.glist,
           x.left
@@ -67,7 +66,7 @@ lav_model_hessian <- function(lavmodel = NULL,
     g.left2 <-
       lav_model_gradient(
         lavmodel = lavmodel,
-        GLIST = lav_model_x2GLIST(
+        GLIST = lav_model_x2glist(
           lavmodel =
             lavmodel, type = type.glist,
           x.left2
@@ -83,7 +82,7 @@ lav_model_hessian <- function(lavmodel = NULL,
     g.right <-
       lav_model_gradient(
         lavmodel = lavmodel,
-        GLIST = lav_model_x2GLIST(
+        GLIST = lav_model_x2glist(
           lavmodel =
             lavmodel, type = type.glist,
           x.right
@@ -99,7 +98,7 @@ lav_model_hessian <- function(lavmodel = NULL,
     g.right2 <-
       lav_model_gradient(
         lavmodel = lavmodel,
-        GLIST = lav_model_x2GLIST(
+        GLIST = lav_model_x2glist(
           lavmodel =
             lavmodel, type = type.glist,
           x.right2
@@ -136,7 +135,7 @@ lav_model_hessian_complex <- function(lavmodel = NULL,
                                       lavcache = NULL,
                                       group.weight = TRUE) {
   gradf <- function(x) {
-    GLIST <- lav_model_x2GLIST(lavmodel = lavmodel, x = x)
+    GLIST <- lav_model_x2glist(lavmodel = lavmodel, x = x)
     dx <- lav_model_gradient(
       lavmodel = lavmodel,
       GLIST = GLIST,
