@@ -18,22 +18,13 @@ lav_model_objective <- function(lavmodel = NULL,
   meanstructure <- lavmodel@meanstructure
   estimator <- lavmodel@estimator
   categorical <- lavmodel@categorical
-  if (.hasSlot(lavmodel, "correlation")) {
-    correlation <- lavmodel@correlation
-  } else {
-    correlation <- FALSE
-  }
+  correlation <- lavmodel@correlation
   group.w.free <- lavmodel@group.w.free
-  fixed.x <- lavmodel@fixed.x
+  # fixed.x <- lavmodel@fixed.x
   conditional.x <- lavmodel@conditional.x
   num.idx <- lavmodel@num.idx
   th.idx <- lavmodel@th.idx
-  if (.hasSlot(lavmodel, "estimator.args")) {
-    estimator.args <- lavmodel@estimator.args
-  } else {
-    estimator.args <- list()
-  }
-
+  estimator.args <- lavmodel@estimator.args
 
   # do we need WLS.est?
   if (estimator %in% c("ULS", "WLS", "DWLS", "NTRLS", "DLS")) {
@@ -59,29 +50,29 @@ lav_model_objective <- function(lavmodel = NULL,
     ) # ,
     # cov.x = lavsamplestats@cov.x)
     if (estimator == "NTRLS") {
-      Sigma.hat <- computeSigmaHat(
+      Sigma.hat <- lav_model_sigma(
         lavmodel = lavmodel, GLIST = GLIST,
         extra = TRUE
       )
-      Mu.hat <- computeMuHat(lavmodel = lavmodel, GLIST = GLIST)
+      Mu.hat <- lav_model_mu(lavmodel = lavmodel, GLIST = GLIST)
     }
     if (estimator == "DLS" && estimator.args$dls.GammaNT == "model") {
-      Sigma.hat <- computeSigmaHat(
+      Sigma.hat <- lav_model_sigma(
         lavmodel = lavmodel, GLIST = GLIST,
         extra = FALSE
       )
-      Mu.hat <- computeMuHat(lavmodel = lavmodel, GLIST = GLIST)
+      Mu.hat <- lav_model_mu(lavmodel = lavmodel, GLIST = GLIST)
     }
     if (lav_debug()) print(WLS.est)
   } else if (estimator %in% c("ML", "GLS", "PML", "FML", "REML", "catML") &&
     lavdata@nlevels == 1L) {
     # compute moments for all groups
     # if(conditional.x) {
-    #    Sigma.hat <- computeSigmaHatJoint(lavmodel = lavmodel,
+    #    Sigma.hat <- lav_model_cond2joint_sigma(lavmodel = lavmodel,
     #                     GLIST = GLIST, lavsamplestats = lavsamplestats,
     #                     extra = (estimator %in% c("ML", "REML","NTRLS")))
     # } else {
-    Sigma.hat <- computeSigmaHat(
+    Sigma.hat <- lav_model_sigma(
       lavmodel = lavmodel, GLIST = GLIST,
       extra = (estimator %in% c(
         "ML", "REML",
@@ -90,9 +81,9 @@ lav_model_objective <- function(lavmodel = NULL,
     )
     # }
 
-    if (estimator == "REML") {
-      LAMBDA <- computeLAMBDA(lavmodel = lavmodel, GLIST = GLIST)
-    }
+    # if (estimator == "REML") {
+    #   LAMBDA <- lav_model_lambda(lavmodel = lavmodel, GLIST = GLIST)
+    # }
 
     # ridge?
     if (lavsamplestats@ridge > 0.0) {
@@ -105,28 +96,28 @@ lav_model_objective <- function(lavmodel = NULL,
 
     if (meanstructure) {
       # if(conditional.x) {
-      #    Mu.hat <- computeMuHatJoint(lavmodel = lavmodel, GLIST = GLIST,
+      #    Mu.hat <- lav_model_cond2joint_mu(lavmodel = lavmodel, GLIST = GLIST,
       #                           lavsamplestats = lavsamplestats)
       # } else {
-      Mu.hat <- computeMuHat(lavmodel = lavmodel, GLIST = GLIST)
+      Mu.hat <- lav_model_mu(lavmodel = lavmodel, GLIST = GLIST)
       # }
     }
 
     if (categorical) {
-      TH <- computeTH(lavmodel = lavmodel, GLIST = GLIST)
+      TH <- lav_model_th(lavmodel = lavmodel, GLIST = GLIST)
     }
 
     if (conditional.x) {
-      PI <- computePI(lavmodel = lavmodel, GLIST = GLIST)
+      PI <- lav_model_pi(lavmodel = lavmodel, GLIST = GLIST)
     }
 
     if (group.w.free) {
-      GW <- computeGW(lavmodel = lavmodel, GLIST = GLIST)
+      GW <- lav_model_gw(lavmodel = lavmodel, GLIST = GLIST)
     }
   } else if (estimator == "MML") {
-    TH <- computeTH(lavmodel = lavmodel, GLIST = GLIST)
-    THETA <- computeTHETA(lavmodel = lavmodel, GLIST = GLIST)
-    GW <- computeGW(lavmodel = lavmodel, GLIST = GLIST)
+    TH <- lav_model_th(lavmodel = lavmodel, GLIST = GLIST)
+    THETA <- lav_model_theta(lavmodel = lavmodel, GLIST = GLIST)
+    GW <- lav_model_gw(lavmodel = lavmodel, GLIST = GLIST)
   }
 
   fx <- 0.0
@@ -139,17 +130,30 @@ lav_model_objective <- function(lavmodel = NULL,
       if (estimator == "ML" && lavdata@nlevels == 1L) {
         # FIML
         if (!attr(Sigma.hat[[g]], "po")) {
-          return(Inf)
+          fx <- as.numeric(Inf)
+          attr(fx, "fx.group") <- rep(as.numeric(Inf), lavsamplestats@ngroups)
+          return(fx)
         }
-        group.fx <- estimator.FIML(
+        # check if h1 is defined (eg zero coverage)
+        if (is.null(lavsamplestats@missing.h1[[g]]$h1)) {
+          #this.h1 <- lav_mvnorm_missing_loglik_samplestats(
+          #  Yp = lavsamplestats@missing[[g]],
+          #  Mu = Mu.hat[[g]], Sigma = Sigma.hat[[g]],
+          #  log2pi = FALSE, minus.two = TRUE) / lavsamplestats@nobs[[g]]
+          #this.h1 <- this.h1 * 0.9999999 # avoid perfect fit
+          this.h1 <- NULL #for now
+        } else {
+          this.h1 <- lavsamplestats@missing.h1[[g]]$h1
+        }
+        group.fx <- lav_model_objective_fiml(
           Sigma.hat = Sigma.hat[[g]],
           Mu.hat = Mu.hat[[g]],
           Yp = lavsamplestats@missing[[g]],
-          h1 = lavsamplestats@missing.h1[[g]]$h1, N = lavsamplestats@nobs[[g]]
+          h1 = this.h1, N = lavsamplestats@nobs[[g]]
         )
       } else if (estimator == "ML" && lavdata@nlevels > 1L) {
         # FIML twolevel
-        group.fx <- estimator.2L(
+        group.fx <- lav_model_objective_2l(
           lavmodel = lavmodel,
           GLIST = GLIST,
           Y1 = lavdata@X[[g]],
@@ -172,7 +176,7 @@ lav_model_objective <- function(lavmodel = NULL,
           lav_msg_stop(gettext("multilevel data not supported for estimator"),
                        estimator)
           }
-        group.fx <- estimator.2L(
+        group.fx <- lav_model_objective_2l(
           lavmodel = lavmodel,
           GLIST = GLIST,
           Lp = lavdata@Lp[[g]],
@@ -181,7 +185,7 @@ lav_model_objective <- function(lavmodel = NULL,
           group = g
         )
       } else if (conditional.x) {
-        group.fx <- estimator.ML_res(
+        group.fx <- lav_model_objective_ml_res(
           Sigma.hat        = Sigma.hat[[g]],
           Mu.hat           = Mu.hat[[g]],
           PI               = PI[[g]],
@@ -193,7 +197,7 @@ lav_model_objective <- function(lavmodel = NULL,
           mean.x           = lavsamplestats@mean.x[[g]]
         )
       } else {
-        group.fx <- estimator.ML(
+        group.fx <- lav_model_objective_ml(
           Sigma.hat        = Sigma.hat[[g]],
           Mu.hat           = Mu.hat[[g]],
           data.cov         = lavsamplestats@cov[[g]],
@@ -206,7 +210,7 @@ lav_model_objective <- function(lavmodel = NULL,
 
       ### GLS #### (0.6-10: not using WLS function any longer)
     } else if (estimator == "GLS") {
-      group.fx <- estimator.GLS(
+      group.fx <- lav_model_objective_gls(
         Sigma.hat        = Sigma.hat[[g]],
         Mu.hat           = Mu.hat[[g]],
         data.cov         = lavsamplestats@cov[[g]],
@@ -258,7 +262,7 @@ lav_model_objective <- function(lavmodel = NULL,
         # WLS.V <- 2*WLS.V
       }
 
-      group.fx <- estimator.WLS(
+      group.fx <- lav_model_objective_wls(
         WLS.est = WLS.est[[g]],
         WLS.obs = lavsamplestats@WLS.obs[[g]],
         WLS.V = WLS.V
@@ -266,7 +270,7 @@ lav_model_objective <- function(lavmodel = NULL,
       attr(group.fx, "WLS.est") <- WLS.est[[g]]
     } else if (estimator == "DWLS" || estimator == "ULS") {
       # diagonal weight matrix
-      group.fx <- estimator.DWLS(
+      group.fx <- lav_model_objective_dwls(
         WLS.est = WLS.est[[g]],
         WLS.obs = lavsamplestats@WLS.obs[[g]],
         WLS.VD = lavsamplestats@WLS.VD[[g]]
@@ -275,7 +279,7 @@ lav_model_objective <- function(lavmodel = NULL,
     } else if (estimator == "PML") {
       # Pairwise maximum likelihood
       if (lavdata@nlevels > 1L) {
-        # group.fx <- estimator.PML.2L(lavmodel       = lavmodel,
+        # group.fx <- lav_model_objective_pml.2L(lavmodel       = lavmodel,
         #                             GLIST          = GLIST,
         #                             Lp             = lavdata@Lp[[g]],
         #                             lavsamplestats = lavsamplestats,
@@ -283,7 +287,7 @@ lav_model_objective <- function(lavmodel = NULL,
         group.fx <- 0 # for now
         attr(group.fx, "logl") <- 0
       } else if (conditional.x) {
-        group.fx <- estimator.PML(
+        group.fx <- lav_model_objective_pml(
           Sigma.hat = Sigma.hat[[g]],
           Mu.hat = Mu.hat[[g]],
           TH = TH[[g]],
@@ -297,7 +301,7 @@ lav_model_objective <- function(lavmodel = NULL,
           missing = lavdata@missing
         )
       } else {
-        group.fx <- estimator.PML(
+        group.fx <- lav_model_objective_pml(
           Sigma.hat = Sigma.hat[[g]],
           Mu.hat = Mu.hat[[g]],
           TH = TH[[g]],
@@ -314,7 +318,7 @@ lav_model_objective <- function(lavmodel = NULL,
       logl.group[g] <- attr(group.fx, "logl")
     } else if (estimator == "FML") {
       # Full maximum likelihood (underlying multivariate normal)
-      group.fx <- estimator.FML(
+      group.fx <- lav_model_objective_fml(
         Sigma.hat = Sigma.hat[[g]],
         TH = TH[[g]],
         th.idx = th.idx[[g]],
@@ -324,7 +328,7 @@ lav_model_objective <- function(lavmodel = NULL,
       )
     } else if (estimator == "MML") {
       # marginal maximum likelihood
-      group.fx <- estimator.MML(
+      group.fx <- lav_model_objective_mml(
         lavmodel = lavmodel,
         GLIST = GLIST,
         THETA = THETA[[g]],
@@ -337,7 +341,7 @@ lav_model_objective <- function(lavmodel = NULL,
       )
     } else if (estimator == "REML") {
       # restricted/residual maximum likelihood
-      group.fx <- estimator.REML(
+      group.fx <- lav_model_objective_reml(
         Sigma.hat = Sigma.hat[[g]],
         Mu.hat = Mu.hat[[g]],
         data.cov = lavsamplestats@cov[[g]],
