@@ -155,9 +155,9 @@ lav_options_set <- function(opt = NULL) {                     # nolint
   opt <- lav_options_check(opt, opt.check, "")
 
   # check option 'start'
-  if (is.character(opt$start) && all(opt$start != c("default", "simple", "est")))
+  if (is.character(opt$start) && all(opt$start != c("default", "simple")))
     lav_msg_stop(gettext(
-      "start option must be 'default', 'simple', 'est' or a parametertable"))
+      "start option must be 'default', 'simple', a fitted object, a vector of parameter values, or a parameter table"))
 
   # first of all: set estimator ####
   if (opt$estimator == "default") {
@@ -193,6 +193,9 @@ lav_options_set <- function(opt = NULL) {                     # nolint
   # rename names of test statistics if needed, check for invalid values ####
   opt$test <- lav_test_rename(opt$test, check = TRUE)
 
+  # same for standard.test
+  opt$standard.test <- lav_test_rename(opt$standard.test, check = TRUE)
+
   # same for scaled.test
   opt$scaled.test <- lav_test_rename(opt$scaled.test, check = TRUE)
 
@@ -240,12 +243,13 @@ lav_options_set <- function(opt = NULL) {                     # nolint
 
   # if categorical, and group.equal contains "intercepts", also add
   # thresholds (and vice versa)
-  if (opt$.categorical && any("intercepts" == opt$group.equal)) {
-    opt$group.equal <- unique(c(opt$group.equal, "thresholds"))
-  }
-  if (opt$.categorical && any("thresholds" == opt$group.equal)) {
-    opt$group.equal <- unique(c(opt$group.equal, "intercepts"))
-  }
+  # not any longer since 0.6-20
+  #if (opt$.categorical && any("intercepts" == opt$group.equal)) {
+  #  opt$group.equal <- unique(c(opt$group.equal, "thresholds"))
+  #}
+  #if (opt$.categorical && any("thresholds" == opt$group.equal)) {
+  #  opt$group.equal <- unique(c(opt$group.equal, "intercepts"))
+  #}
 
   # clustered ####
   # brute-force override (for now)
@@ -367,7 +371,8 @@ lav_options_set <- function(opt = NULL) {                     # nolint
     ))) {
       lav_msg_stop(gettextf(
         "missing=%1$s is not allowed for estimator %2$s",
-        dQuote(opt$missing), dQuote(lav_options_estimatorgroup(opt$estimator))))
+        dQuote(opt$missing),
+        dQuote(lav_options_estimatorgroup(opt$estimator.orig))))
     }
   } else if (opt$missing == "ml.x") {
     if (opt$.categorical) {
@@ -381,7 +386,8 @@ lav_options_set <- function(opt = NULL) {                     # nolint
     ))) {
       lav_msg_stop(gettextf(
         "missing=%1$s is not allowed for estimator %2$s",
-        dQuote(opt$missing), dQuote(lav_options_estimatorgroup(opt$estimator))))
+        dQuote(opt$missing),
+        dQuote(lav_options_estimatorgroup(opt$estimator.orig))))
     }
   } else if (opt$missing == "two.stage") {
     if (opt$.categorical) {
@@ -395,7 +401,8 @@ lav_options_set <- function(opt = NULL) {                     # nolint
     ))) {
       lav_msg_stop(gettextf(
         "missing=%1$s is not allowed for estimator %2$s",
-        dQuote(opt$missing), dQuote(lav_options_estimatorgroup(opt$estimator))))
+        dQuote(opt$missing),
+        dQuote(lav_options_estimatorgroup(opt$estimator.orig))))
     }
   } else if (opt$missing == "robust.two.stage") {
     if (opt$.categorical) {
@@ -409,7 +416,8 @@ lav_options_set <- function(opt = NULL) {                     # nolint
     ))) {
       lav_msg_stop(gettextf(
         "missing=%1$s is not allowed for estimator %2$s",
-        dQuote(opt$missing), dQuote(lav_options_estimatorgroup(opt$estimator))))
+        dQuote(opt$missing),
+        dQuote(lav_options_estimatorgroup(opt$estimator.orig))))
     }
   } else if (opt$missing == "doubly.robust") {
     if (opt$estimator != "pml") {
@@ -420,7 +428,8 @@ lav_options_set <- function(opt = NULL) {                     # nolint
   }
 
   # check missing ####
-  if (any(opt$missing == c("ml", "ml.x")) && opt$se == "robust.sem") {
+  if (any(opt$missing == c("ml", "ml.x")) &&
+      opt$se %in% c("robust.sem", "robust.sem.nt")) {
     lav_msg_warn(gettextf(
       "missing will be set to %1$s for se = %2$s.",
       dQuote("listwise"), dQuote(opt$se)))
@@ -635,7 +644,7 @@ lav_options_set <- function(opt = NULL) {                     # nolint
 
   # first.order information can not be used with robust
   if (opt$information[1] == "first.order" &&
-      any(opt$se == c("robust.huber.white", "robust.sem"))) {
+      any(opt$se == c("robust.huber.white", "robust.sem", "robust.sem.nt"))) {
     lav_msg_stop(gettextf(
       "information must be either %s if robust standard errors are requested.",
       lav_msg_view(c("expected", "observed"), log.sep = "or")))
@@ -852,6 +861,15 @@ lav_options_set <- function(opt = NULL) {                     # nolint
   #    opt$test <- unique(opt$test)
   # }
 
+  # add standard.test to test (if not already there)
+  if (opt$standard.test != "standard") {
+    if (length(opt$test) == 1L && opt$test[1] == "standard") {
+      opt$test <- unique(c(opt$test, opt$standard.test))
+    } else {
+      opt$test <- unique(c(opt$standard.test, opt$test))
+    }
+  }
+
   # add scaled.test to test (if not already there)
   if (opt$scaled.test != "standard") {
     if (length(opt$test) == 1L && opt$test[1] == "standard") {
@@ -859,8 +877,10 @@ lav_options_set <- function(opt = NULL) {                     # nolint
     } else {
       opt$test <- unique(c(opt$scaled.test, opt$test))
     }
+  }
 
-    # where does "standard" appear in the opt$test vector?
+  # where does "standard" appear in the opt$test vector?
+  if (opt$test[1] != "none") {
     standard.idx <- which(opt$test == "standard")[1]
     if (is.na(standard.idx)) {
       # "standard" is not in the opt$test vector at all,
@@ -872,7 +892,6 @@ lav_options_set <- function(opt = NULL) {                     # nolint
     }
   }
 
-
   # final check
   wrong.idx <- which(!opt$test %in% c(
     "none", "standard", "satorra.bentler",
@@ -997,7 +1016,7 @@ lav_options_set <- function(opt = NULL) {                     # nolint
   }
 
   # if target, check target matrix, and set order.lv.by to = "none"
-  if (opt$rotation == "target" || opt$rotation == "pst") {
+  if (opt$rotation == "target.strict" || opt$rotation == "pst") {
     target <- opt$rotation.args$target
     if (is.null(target)) {
       lav_msg_stop(gettext("rotation target matrix is NULL"))
@@ -1015,8 +1034,21 @@ lav_options_set <- function(opt = NULL) {                     # nolint
 
   if (opt$rotation == "pst") {
     target.mask <- opt$rotation.args$target.mask
-    if (is.null(target.mask)) {
-      lav_msg_stop(gettext("rotation target.mask matrix is NULL"))
+    if (is.null(target.mask) || length(target.mask) == 0L) {
+      #lav_msg_stop(gettext("rotation target.mask matrix is NULL"))
+      if (is.matrix(target)) {
+        tmp <- matrix(1L, nrow = nrow(target), ncol = ncol(target))
+        tmp[target != 0] <- 0L # ignore these (non-zero) elements
+        opt$rotation.args$target.mask <- target.mask <- tmp
+      } else if (is.list(target)) {
+        out <- lapply(1:length(target), function(g) {
+                 tmp <- matrix(1L, nrow = nrow(target[[g]]),
+                                   ncol = ncol(target[[g]]))
+                 tmp[target[[g]] != 0] <- 0L # ignore these (non-zero) elements
+                 tmp
+               })
+        opt$rotation.args$target.mask <- target.mask <- out
+      }
     }
     if (is.list(target.mask)) {
       if (!all(sapply(target.mask, is.matrix))) {
@@ -1040,9 +1072,11 @@ lav_options_set <- function(opt = NULL) {                     # nolint
   }
 
   # if NAs, force opt$rotation to be 'pst' and create target.mask
-  if (opt$rotation == "target") {
+  if (opt$rotation == "target.strict") {
     # matrix
+    warn.flag <- FALSE
     if (is.matrix(target) && anyNA(target)) {
+      warn.flag <- TRUE
       opt$rotation <- "pst"
       target.mask <- matrix(1, nrow = nrow(target), ncol = ncol(target))
       target.mask[is.na(target)] <- 0
@@ -1053,6 +1087,7 @@ lav_options_set <- function(opt = NULL) {                     # nolint
       ngroups <- length(target)
       for (g in seq_len(ngroups)) {
         if (anyNA(target[[g]])) {
+          warn.flag <- TRUE
 		  # is target.mask just a <0 x 0 matrix>? create list!
 		  if (is.matrix(opt$rotation.args$target.mask)) {
 		    opt$rotation.args$target.mask <- vector("list", length = ngroups)
@@ -1065,6 +1100,9 @@ lav_options_set <- function(opt = NULL) {                     # nolint
         }
       }
     }
+    if (warn.flag) {
+       lav_msg_warn(gettext("switching to PST rotation as target matrix contains NA values"))
+    }
   }
 
   # set row.weights
