@@ -2,6 +2,28 @@
 
 lavaan_cache_env <- new.env(parent = emptyenv())
 
+# # function to get or set the switch to use c++ code in lavaanC
+# lav_use_lavaanC <- uselavaanC <- function(x) {
+#   if (missing(x)) {
+#     if (!exists("opt.lavaanC", lavaan_cache_env)) {
+#       assign("opt.lavaanC", requireNamespace("lavaanC", quietly = TRUE), lavaan_cache_env)
+#     }
+#     return(get("opt.lavaanC", lavaan_cache_env))
+#   } else {
+#     if (!is.logical(x) || length(x) != 1L)
+#       lav_msg_stop(gettext("'x' must be a scalar logical"))
+#     if (x) {
+#       if (!requireNamespace("lavaanC", quietly = TRUE)) {
+#         lav_msg_warn(gettext("cannot use lavaanC, package not found."))
+#         assign("opt.lavaanC", FALSE, lavaan_cache_env)
+#         return(invisible(NULL))
+#       }
+#     }
+#     assign("opt.lavaanC", x, lavaan_cache_env)
+#     return(invisible(NULL))
+#   }
+# }
+
 # functions to handle warn/debug/verbose options
 #             (no longer in 'standard' options)
 # if x not present returns the current value of opt.warn/debug/verbose
@@ -169,6 +191,10 @@ lav_options_default <- function() {
                                  regression = "lm", lisrel = "EQS",
                                  eqs = "EQS", lm = "lm", mplus = "Mplus"
   ))
+  elm("gls.v11.mplus", "default", chr = "default", bl = TRUE)
+  elm("gamma.vcov.mplus", "default", chr = "default", bl = TRUE)
+  elm("gamma.wls.mplus", "default", chr = "default", bl = TRUE)
+  elm("information.expected.mplus", "default", chr = "default", bl = TRUE)
 
   # model modifiers
   elm("meanstructure", "default", chr = "default", bl = TRUE)
@@ -199,6 +225,7 @@ lav_options_default <- function() {
   elm("auto.th", FALSE, bl = TRUE)
   elm("auto.delta", FALSE, bl = TRUE)
   elm("auto.efa", FALSE, bl = TRUE)
+  elm("composites", TRUE, bl = TRUE)
 
   # rotation
   elm("rotation", "geomin", chr = c(crawfer = "cf", crawford.ferguson = "cf",
@@ -208,10 +235,10 @@ lav_options_default <- function() {
     entropy = "entropy", mccammon = "mccammon", infomax = "infomax",
     tandem1 = "tandem1", tandem2 = "tandem2", none = "none", promax = "promax",
     oblimax = "oblimax", bentler = "bentler", simplimax = "simplimax",
-    target = "target", pst = "pst", cf.quartimax = "cf-quartimax",
-    cf.varimax = "cf-varimax", cf.equamax = "cf-equamax",
-    cf.parsimax = "cf-parsimax", cf.facparsim = "cf-facparsim",
-    bi.quartimin = "biquartimin",
+    target.strict = "target.strict", target = "pst", pst = "pst",
+    cf.quartimax = "cf-quartimax", cf.varimax = "cf-varimax",
+    cf.equamax = "cf-equamax", cf.parsimax = "cf-parsimax",
+    cf.facparsim = "cf-facparsim", bi.quartimin = "biquartimin",
     biquartimin = "biquartimin", bi.geomin = "bigeomin", bigeomin = "bigeomin"
   ))
   elm("rotation.se", "bordered", chr = c("delta", "bordered"))
@@ -222,15 +249,15 @@ lav_options_default <- function() {
     default = "default", kaiser = "kaiser", none = "none",
     cureton.mulaik = "cm", cm = "cm"))
   elm(c("rotation.args", "std.ov"), TRUE, bl = TRUE)
-  elm(c("rotation.args", "geomin.epsilon"), 0.001, nm = "]0, 0.01]")
+  elm(c("rotation.args", "geomin.epsilon"), 0.001, nm = "]0, 1.00]")
   # was 0.01 < 0.6-10
   elm(c("rotation.args", "orthomax.gamma"), 1, nm = "[0, 1]")
   elm(c("rotation.args", "cf.gamma"), 0, nm = "[0, 1]")
   elm(c("rotation.args", "oblimin.gamma"), 0, nm = "[0, 1000]")
   elm(c("rotation.args", "promax.kappa"), 4, nm = "[0, 1000]")
-  elm(c("rotation.args", "target"), matrix(0, 0, 0), oklen = c(0L, 1000L))
-  elm(c("rotation.args", "target.mask"), matrix(0, 0, 0), oklen = c(0L, 1000L))
-  elm(c("rotation.args", "rstarts"), 30L, nm = "[0, 1000000]")
+  elm(c("rotation.args", "target"), matrix(0, 0L, 0L), oklen = c(0, 1e+32))
+  elm(c("rotation.args", "target.mask"), matrix(0, 0L, 0L), oklen = c(0, 1e+32))
+  elm(c("rotation.args", "rstarts"), 30L, nm = "[0, 1e+07]")
   elm(c("rotation.args", "algorithm"), "gpa", chr = c("gpa", "pairwise"))
   elm(c("rotation.args", "reflect"), TRUE, bl = TRUE)
   elm(c("rotation.args", "order.lv.by"), "index",
@@ -240,7 +267,7 @@ lav_options_default <- function() {
   elm(c("rotation.args", "warn"), FALSE, bl = TRUE)
   elm(c("rotation.args", "verbose"), FALSE, bl = TRUE)
   elm(c("rotation.args", "jac.init.rot"), TRUE, bl = TRUE)
-  elm(c("rotation.args", "max.iter"), 10000L, nm = "[0, 1000000]")
+  elm(c("rotation.args", "max.iter"), 10000L, nm = "[0, 1e+12]")
 
   # full data
   elm("std.ov", FALSE, bl = TRUE)
@@ -273,6 +300,7 @@ lav_options_default <- function() {
   elm("group.label", NULL, oklen = c(0L, 100L)) # no checks
   elm("group.equal", "", chr =
         c("", "none", "loadings", "intercepts", "means", "composite.loadings",
+          "composite.weights",
           "regressions", "residuals", "residual.covariances", "thresholds",
           "lv.variances", "lv.covariances"), oklen = c(0L, 100L))
   elm("group.partial", "", oklen = c(0L, 100L)) # no checks
@@ -307,7 +335,7 @@ lav_options_default <- function() {
   elm("bounds", "none", chr = c(
     "none", "default", "standard", "user", "wide", "wide.zerovar", "pos.var",
     "pos.ov.var", "pos.lv.var"))      # new in 0.6-6
-  elm("rstarts", 0L, nm = "[0, 1000]", num2int = TRUE) # new in 0.6-18
+  elm("rstarts", 0L, nm = "[0, 10000]", num2int = TRUE) # new in 0.6-18
 
   # inference
   elm("se", "default", chr = c(
@@ -316,8 +344,10 @@ lav_options_default <- function() {
     robust.cluster = "robust.cluster",
     robust.cluster.sem = "robust.cluster.sem",
     sandwich = "robust.huber.white", robust.sem = "robust.sem",
+    robust.sem.nt = "robust.sem.nt",
     two.stage = "two.stage", robust.two.stage = "robust.two.stage",
     bootstrap = "bootstrap", boot = "bootstrap", first.order = "first.order",
+    robust.mlm.nt = "robust.sem.nt",
     robust.mlm = "robust.sem", robust.mlr = "robust.huber.white",
     observed = "observed", expected = "expected"),
     oklen = c(1L, -1L)
@@ -327,7 +357,8 @@ lav_options_default <- function() {
 
   # information (se + test)
   elm("information", c("default", "default"), chr = c(
-    "default", "expected", "observed", "first.order"), oklen = c(1L, 2L))
+    "default", "expected", "observed", "first.order"),
+    oklen = c(1L, 2L))
   elm("h1.information", c("structured", "structured"), chr = c(
     "structured", "unstructured"), oklen =  c(1L, 2L))
   elm("observed.information", c("hessian", "default"), chr = c(
@@ -353,6 +384,9 @@ lav_options_default <- function() {
     "default", "structured", "unstructured"
   ))
 
+  # test statistic for fit measures
+  elm("standard.test", "standard", oklen = c(1L, 100L))
+
   # test statistic for scaling
   elm("scaled.test", "standard", oklen = c(1L, 100L))
 
@@ -425,6 +459,7 @@ lav_options_default <- function() {
 
   # sanity checks
   elm("check.start", TRUE, bl = TRUE)
+  elm("check.sigma.pd", "chol", chr = c("chol", "eigen")) # stored in env
   elm("check.post", TRUE, bl = TRUE)
   elm("check.gradient", TRUE, bl = TRUE)
   elm("check.vcov", TRUE, bl = TRUE)
@@ -436,6 +471,7 @@ lav_options_default <- function() {
   elm("h1", TRUE, bl = TRUE)
   elm("baseline", TRUE, bl = TRUE)
   elm("baseline.conditional.x.free.slopes", TRUE, bl = TRUE)
+  elm("baseline.fixed.x.free.cov", TRUE, bl = TRUE)
   elm("implied", TRUE, bl = TRUE)
   elm("loglik", TRUE, bl = TRUE)
 
@@ -444,14 +480,21 @@ lav_options_default <- function() {
 
   # internal
   elm("parser", "new", chr = c(old = "old", orig = "old", new = "new",
-                               classic = "old"))
+                               c.r = "c.r", cr = "c.r", classic = "old"))
 
   # categorical
   elm("categorical", "default", chr = "default", bl = TRUE)
 
+  # sort list and sublists
+  for (nm in names(opt.default)) {
+      if (is.list(opt.default[[nm]]))
+        opt.default[[nm]] <- opt.default[[nm]][sort(names(opt.default[[nm]]))]
+    }
+  opt.default <- opt.default[sort(names(opt.default))]
   # ------------- store info in lavaan environment ---------------
   assign("opt.default", opt.default, lavaan_cache_env)
   assign("opt.check", opt.check, lavaan_cache_env)
+  assign("opt.check.sigma.pd", "chol", lavaan_cache_env)
 
   # return defaults
   return(opt.default)
