@@ -283,8 +283,9 @@ lav_options_est_dwls <- function(opt) {
       opt$estimator %in% c("wlsm", "wlsmv", "wlsmvs")) {
     lav_msg_stop(gettext("use (D)WLS estimator for bootstrap"))
   } else if (opt$se == "default") {
-    if (opt$estimator == "dwls") {
-      opt$se <- "standard"
+    if (opt$estimator == "dwls" && !opt$.categorical) {
+      # opt$se <- "standard"
+      opt$se <- "robust.sem.nt" # new in 0.6-21
     } else {
       opt$se <- "robust.sem"
     }
@@ -294,11 +295,16 @@ lav_options_est_dwls <- function(opt) {
   # test
   if (!opt$test[1] == "none") {
     if (opt$estimator == "dwls") {
-      if (opt$test[1] == "default") {
-        opt$test <- "standard"
-      } # else {
-      #  opt$test <- union("standard", opt$test)
-      # }
+      if (opt$test[1] == "default" && !opt$.categorical) {
+        #opt$test <- "standard"
+        opt$test <- "browne.residual.nt"
+        opt$standard.test <- "browne.residual.nt"
+        opt$scaled.test <- "browne.residual.nt"
+      } else if (opt$test[1] == "default" && opt$.categorical) {
+        opt$test <- "standard" # bad choice!
+      } else {
+        opt$test <- union("standard", opt$test)
+      }
     } else if (opt$estimator == "wlsm") {
       if (opt$test[1] == "default") {
         opt$test <- "satorra.bentler"
@@ -329,8 +335,9 @@ lav_options_est_uls <- function(opt) {
       opt$estimator %in% c("ulsm", "ulsmv", "ulsmvs")) {
     lav_msg_stop(gettext("use ULS estimator for bootstrap"))
   } else if (opt$se == "default") {
-    if (opt$estimator == "uls") {
-      opt$se <- "standard"
+    if (opt$estimator == "uls" && !opt$.categorical) {
+      #opt$se <- "standard"
+      opt$se <- "robust.sem.nt" # new in 0.6-21
     } else {
       opt$se <- "robust.sem"
     }
@@ -340,11 +347,15 @@ lav_options_est_uls <- function(opt) {
   # test
   if (!opt$test[1] == "none") {
     if (opt$estimator == "uls") {
-      if (opt$test[1] == "default") {
+      if (opt$test[1] == "default" && !opt$.categorical) {
+        opt$test <- "browne.residual.nt" # new in 0.6-21
+        opt$standard.test <- "browne.residual.nt"
+        opt$scaled.test <- "browne.residual.nt"
+      } else if (opt$test[1] == "default" && opt$.categorical) {
         opt$test <- "standard"
-      } # else {
-      #  opt$test <- union("standard", opt$test)
-      # }
+      } else {
+        opt$test <- union("standard", opt$test)
+      }
     } else if (opt$estimator == "ulsm") {
       if (opt$test[1] == "default") {
         opt$test <- "satorra.bentler"
@@ -536,10 +547,14 @@ lav_options_est_fabin <- function(opt) {
   if (lav_options_estimatorgroup(opt$estimator) == "MGM") {
     if (is.null(opt$estimator.args)) {
       opt$estimator.args <- list(
+        zero.after.efa = TRUE,
         psi.mapping = FALSE,
         quadprog = FALSE
       )
     } else {
+      if (is.null(opt$estimator.args$zero.after.efa)) {
+        opt$estimator.args$zero.after.efa <- TRUE
+      }
       if (is.null(opt$estimator.args$psi.mapping)) {
         opt$estimator.args$psi.mapping <- FALSE
       }
@@ -596,4 +611,4 @@ lav_options_est_none <- function(opt) {
     opt$test <- "none"
   }
   opt
-}
\ No newline at end of file
+}
