@@ -1,6 +1,6 @@
 # build def function from partable
 lav_partable_constraints_def <- function(partable, con = NULL, debug = FALSE,
-                                         txtOnly = FALSE) {
+                                         txtOnly = FALSE, warn = TRUE) {
   if (!missing(debug)) {
     current.debug <- lav_debug()
     if (lav_debug(debug))
@@ -28,6 +28,16 @@ lav_partable_constraints_def <- function(partable, con = NULL, debug = FALSE,
     }
   }
 
+  # sort order of def.idx by dependencies
+  deps <- lapply(partable$rhs[def.idx], FUN = function(x) {
+                                                all.vars(parse(text=x)) })
+  lab.unsorted <- partable$lhs[def.idx]
+  adj.mat <- matrix(0L, nrow = length(def.idx), ncol = length(def.idx))
+  for (i in seq_along(lab.unsorted)) {
+    adj.mat[lab.unsorted %in% deps[[i]], i] <- 1L
+  }
+  def.idx <- def.idx[lav_graph_order_adj_mat(adj.mat, warn = warn)]
+
   # create function
   formals(def.function) <- alist(.x. = , ... = )
   if (txtOnly) {
@@ -151,7 +161,8 @@ lav_partable_constraints_ceq <- function(partable, con = NULL, debug = FALSE,
   }
 
   # first come the variable definitions
-  DEF.txt <- lav_partable_constraints_def(partable, txtOnly = TRUE)
+  DEF.txt <- lav_partable_constraints_def(partable, txtOnly = TRUE,
+                                          warn = FALSE)
   def.idx <- which(partable$op == ":=")
   BODY.txt <- paste(BODY.txt, DEF.txt, "\n", sep = "")
 
@@ -339,7 +350,8 @@ lav_partable_constraints_ciq <- function(partable, con = NULL, debug = FALSE,
   }
 
   # first come the variable definitions
-  DEF.txt <- lav_partable_constraints_def(partable, txtOnly = TRUE)
+  DEF.txt <- lav_partable_constraints_def(partable, txtOnly = TRUE,
+                                          warn = FALSE)
   def.idx <- which(partable$op == ":=")
   BODY.txt <- paste(BODY.txt, DEF.txt, "\n", sep = "")
 
@@ -444,7 +456,7 @@ lav_partable_constraints_ciq <- function(partable, con = NULL, debug = FALSE,
       xlab <- paste(".x.[", FREE[ineq.idx[i]], "]", sep = "")
       ineq.string <- paste(xlab, " - (", val, ")", sep = "")
     }
- 
+
     BODY.txt <- paste(BODY.txt, "out[", i, "] <- ", ineq.string, "\n", sep = "")
   }
 
@@ -541,3 +553,4 @@ lav_partable_constraints_label_id <- function(partable, con = NULL,
 
   con.x.idx
 }
+
