@@ -452,7 +452,7 @@ lav_partable_indep_or_unrestricted <- function(lavobject = NULL,
 
       # fixed.x exogenous variables?
       if (!conditional.x && (nx <- length(ov.names.x)) > 0L) {
-        if (independent && lavoptions$mimic %in% c("Mplus", "lavaan")) {
+        if (independent && lavoptions$baseline.fixed.x.free.cov) {
           # add covariances for eXo
           pstar <- nx * (nx - 1) / 2
           if (pstar > 0L) { # only if more than 1 variable
@@ -673,8 +673,9 @@ lav_partable_indep_or_unrestricted <- function(lavobject = NULL,
 lav_partable_unrestricted_chol <- function(lavobject = NULL,
                                            # if no object is available,
                                            lavdata = NULL,
-                                           lavpta = NULL,
-                                           lavoptions = NULL) {
+                                           lavpta = NULL, # optional
+                                           lavoptions = NULL,
+                                           group = NULL) {
   # grab everything from lavaan lavobject
   if (!is.null(lavobject)) {
     stopifnot(inherits(lavobject, "lavaan"))
@@ -695,6 +696,17 @@ lav_partable_unrestricted_chol <- function(lavobject = NULL,
   ngroups <- lavdata@ngroups
   nlevels <- lavdata@nlevels
 
+  # select groups
+  if (is.null(group)) {
+    group.select <- seq_len(ngroups)
+  } else {
+    stopifnot(is.numeric(group), all(group <= ngroups))
+    group.select <- group
+    if (length(group.select) == 0L) {
+      lav_msg_stop(gettext("no groups selected"))
+    }
+  }
+
   # what with fixed.x?
   # - does not really matter; fit will be saturated anyway
   # - fixed.x = TRUE may avoid convergence issues with non-numeric
@@ -715,6 +727,12 @@ lav_partable_unrestricted_chol <- function(lavobject = NULL,
   # block number
   b <- 0L
   for (g in 1:ngroups) {
+
+    # select group?
+    if (! g %in% group.select) {
+      next
+    }
+
     # only for multilevel
     if (nlevels > 1L) {
       Lp <- lavdata@Lp[[g]]
