@@ -31,7 +31,16 @@
 
 setMethod(
   "residuals", "lavaan",
-  function(object, type = "raw", labels = TRUE) {
+  function(object, type = "raw", labels = TRUE, ...) {
+    dotdotdot <- list(...)
+    if (length(dotdotdot) > 0L) {
+      for (j in seq_along(dotdotdot)) {
+        lav_msg_warn(gettextf(
+          "Unknown argument %s for %s", sQuote(names(dotdotdot)[j]),
+          sQuote("residuals"))
+        )
+      }
+    }
     # lowercase type
     type <- tolower(type)
 
@@ -56,7 +65,16 @@ setMethod(
 
 setMethod(
   "resid", "lavaan",
-  function(object, type = "raw") {
+  function(object, type = "raw", ...) {
+    dotdotdot <- list(...)
+    if (length(dotdotdot) > 0L) {
+      for (j in seq_along(dotdotdot)) {
+        lav_msg_warn(gettextf(
+          "Unknown argument %s for %s", sQuote(names(dotdotdot)[j]),
+          sQuote("resid"))
+        )
+      }
+    }
     residuals(object, type = type, labels = TRUE)
   }
 )
@@ -155,6 +173,9 @@ lav_residuals <- function(object, type = "raw", h1 = TRUE, custom.rmr = NULL,
                           rename.cov.cor = FALSE,
                           add.labels = FALSE, add.class = FALSE,
                           drop.list.single.group = FALSE) {
+  # check object
+  object <- lav_object_check_version(object)
+
   # type
   type <- tolower(type)[1]
 
@@ -625,7 +646,7 @@ lav_residuals_se <- function(object, type = "raw", z.type = "standardized",
       cov.se <- lav_matrix_vech_reverse(tmp, diagonal = FALSE)
 
       # MEAN
-      mean.se <- rep(as.numeric(NA), nth)
+      mean.se <- rep(as.numeric(NA), nvar)
 
       # TH
       th.se <- sqrt(diag.ACOV[1:nth])
@@ -645,7 +666,6 @@ lav_residuals_se <- function(object, type = "raw", z.type = "standardized",
         th.se = th.se
       )
 
-
       # continuous -- single level
     } else if (lavdata@nlevels == 1L) {
       if (lavmodel@conditional.x) {
@@ -1057,7 +1077,11 @@ lav_residuals_summary <- function(object, type = c("rmr", "srmr", "crmr"),
           pstar <- length(STATS)
           if (type[typ] == "crmr") {
             # pstar <- pstar - ( nvar - nvar.x )
-            pstar <- pstar - nvar
+            if (conditional.x) {
+              pstar <- pstar - nrow(rmsList.g[["res.cov"]])
+            } else {
+              pstar <- pstar - nvar
+            }
           }
 
           ACOV <- NULL
@@ -1508,7 +1532,7 @@ lav_residuals_summary_old <- function(resList = NULL,
 }
 
 
-# x is a list with sample statistics (eg output of inspect(fit, "sampstat")
+# x is a list with sample statistics (eg output of lavInspect(fit, "sampstat")
 # y is another (possibly the same) list with sample statistics
 #
 # to avoid many 'NAs', we set the scale-factor to 1
