@@ -7,6 +7,10 @@
 lavTest <- function(lavobject, test = "standard",
                     scaled.test = "standard",
                     output = "list", drop.list.single = TRUE) {
+
+  # check object
+  lavobject <- lav_object_check_version(lavobject)
+
   # check output
   output.valid <- c("list", "text")
   if (!any(output == output.valid)) {
@@ -18,6 +22,11 @@ lavTest <- function(lavobject, test = "standard",
   # extract 'test' slot
   TEST <- lavobject@test
 
+  # backwards compatibility:
+  # if (length(TEST) > 0L && is.null(names(TEST))) {
+  #   names(TEST) <- sapply(TEST, "[[", "test")
+  # }
+
   # which test?
   if (!missing(test)) {
     # check 'test'
@@ -51,7 +60,7 @@ lavTest <- function(lavobject, test = "standard",
       return(list())
     } else if (any(test %in% c("bootstrap", "bollen.stine"))) {
       lav_msg_stop(gettext(
-      "please use bootstrapLavaan() to obtain a bootstrap based test statistic."
+      "please use lavBootstrap() to obtain a bootstrap based test statistic."
       ))
     }
 
@@ -341,10 +350,10 @@ lav_model_test <- function(lavobject = NULL,
   if (lavoptions$estimator == "PML" && test[1] != "none") {
     # attention!
     # if the thresholds are saturated (ie, nuisance parameters)
-    # we should use the ctr_pml_plrt() function.
+    # we should use the lav_pml_plrt() function.
     #
     # BUT, if the thresholds are structured (eg equality constraints)
-    # then we MUST use the ctr_pml_plrt2() function.
+    # then we MUST use the lav_pml_plrt2() function.
     #
     # This was not done automatically < 0.6-6
     #
@@ -369,11 +378,11 @@ lav_model_test <- function(lavobject = NULL,
       }
     }
 
-    # switch between ctr_pml_plrt() and ctr_pml_plrt2()
+    # switch between lav_pml_plrt() and lav_pml_plrt2()
     if (thresholds.structured) {
-      pml_plrt <- ctr_pml_plrt2
+      pml_plrt <- lav_pml_plrt2
     } else {
-      pml_plrt <- ctr_pml_plrt
+      pml_plrt <- lav_pml_plrt
     }
 
     PML <- pml_plrt(
@@ -399,6 +408,12 @@ lav_model_test <- function(lavobject = NULL,
     } else {
       chisq.group <- rep(as.numeric(NA), lavdata@ngroups)
     }
+  } else if (lavdata@missing == "ml" && any(lavdata@Mp[[1]]$coverage == 0)) {
+    if (length(lavh1) > 0L) {
+      chisq.group <- -2 * (lavloglik$loglik.group - lavh1$logl$loglik.group)
+    } else {
+      chisq.group <- rep(as.numeric(NA), lavdata@ngroups)
+    }
   } else {
     # get fx.group
     fx <- attr(x, "fx")
@@ -429,7 +444,7 @@ lav_model_test <- function(lavobject = NULL,
 
   # reference distribution: always chi-square, except for the
   # non-robust version of ULS and PML
-  if (lavoptions$estimator == "ULS" || lavoptions$estimator == "PML") {
+  if (lavoptions$estimator %in% c("ULS", "DWLS", "PML")) {
     refdistr <- "unknown"
     pvalue <- as.numeric(NA)
   } else {
@@ -579,7 +594,6 @@ lav_model_test <- function(lavobject = NULL,
         WLS.V = attr(VCOV, "WLS.V"),
         Gamma = attr(VCOV, "Gamma"),
         test = this.test,
-        mimic = lavoptions$mimic,
         method = "original", # since 0.6-13
         return.ugamma = FALSE
       )
