@@ -31,6 +31,13 @@ lav_test_diff_Satorra2000 <- function(m1, m0, H1 = TRUE, A.method = "delta",
     ))
   }
 
+  # check for (near) identical test statistics (despite m > 0)
+  if (abs(T1 - T0) < sqrt(.Machine$double.eps)) {
+    lav_msg_warn(gettext("the test statistic of the restriced model is (nearly)
+                         identical to the test statistic of the full model;
+                         check your models."))
+  }
+
 
   # bail out here, if m == 0 (but we should catch this earlier)
   # if(m < 1L) {
@@ -51,7 +58,7 @@ lav_test_diff_Satorra2000 <- function(m1, m0, H1 = TRUE, A.method = "delta",
 
   if (H1) {
     WLS.V <- lavTech(m1, "WLS.V")
-    PI <- computeDelta(m1@Model)
+    PI <- lav_model_delta(m1@Model)
     P <- lavTech(m1, "information")
     # needed? (yes, if H1 already has eq constraints)
     P.inv <- lav_model_information_augment_invert(m1@Model,
@@ -67,8 +74,7 @@ lav_test_diff_Satorra2000 <- function(m1, m0, H1 = TRUE, A.method = "delta",
       if (A.method == "delta") {
         if (m1@Model@eq.constraints) {
           A <- A %*% t(m1@Model@eq.constraints.K)
-        } else if (.hasSlot(m1@Model, "ceq.simple.only") &&
-          m1@Model@ceq.simple.only) {
+        } else if (m1@Model@ceq.simple.only) {
           A <- A %*% t(m1@Model@ceq.simple.K)
         }
       }
@@ -78,7 +84,7 @@ lav_test_diff_Satorra2000 <- function(m1, m0, H1 = TRUE, A.method = "delta",
     lav_msg_stop(gettext("not ready yet"))
 
     WLS.V <- lavTech(m0, "WLS.V")
-    PI <- computeDelta(m0@Model)
+    PI <- lav_model_delta(m0@Model)
     P <- lavTech(m0, "information")
     # needed?
     P.inv <- lav_model_information_augment_invert(m0@Model,
@@ -95,8 +101,7 @@ lav_test_diff_Satorra2000 <- function(m1, m0, H1 = TRUE, A.method = "delta",
       # take into account equality constraints m1
       if (m0@Model@eq.constraints) {
         A <- A %*% t(m0@Model@eq.constraints.K)
-      } else if (.hasSlot(m0@Model, "ceq.simple.only") &&
-        m0@Model@ceq.simple.only) {
+      } else if (m0@Model@ceq.simple.only) {
         A <- A %*% t(m0@Model@ceq.simple.K)
       }
       if (lav_debug()) print(A)
@@ -118,6 +123,13 @@ lav_test_diff_Satorra2000 <- function(m1, m0, H1 = TRUE, A.method = "delta",
   if (length(empty.idx) > 0) {
     A <- A[-empty.idx, , drop = FALSE]
   }
+  if (nrow(A) == 0L) {
+    # oops... abort!
+    return(list(
+      T.delta = (T0 - T1), scaling.factor = as.numeric(NA),
+      df.delta = m, a = as.numeric(NA), b = as.numeric(NA)
+    ))
+  }
 
   # PAAPAAP
   PAAPAAP <- P.inv %*% t(A) %*% MASS::ginv(A %*% P.inv %*% t(A)) %*% A %*% P.inv
@@ -421,24 +433,22 @@ lav_test_diff_A <- function(m1, m0, method = "delta", reference = "H1") {
     }
   } else if (method == "delta") {
     # use a numeric approximation of `A'
-    Delta1.list <- computeDelta(m1@Model)
-    Delta0.list <- computeDelta(m0@Model)
+    Delta1.list <- lav_model_delta(m1@Model)
+    Delta0.list <- lav_model_delta(m0@Model)
     Delta1 <- do.call(rbind, Delta1.list)
     Delta0 <- do.call(rbind, Delta0.list)
 
     # take into account equality constraints m0
     if (m0@Model@eq.constraints) {
       Delta0 <- Delta0 %*% m0@Model@eq.constraints.K
-    } else if (.hasSlot(m0@Model, "ceq.simple.only") &&
-      m0@Model@ceq.simple.only) {
+    } else if (m0@Model@ceq.simple.only) {
       Delta0 <- Delta0 %*% t(m0@Model@ceq.simple.K)
     }
 
     # take into account equality constraints m1
     if (m1@Model@eq.constraints) {
       Delta1 <- Delta1 %*% m1@Model@eq.constraints.K
-    } else if (.hasSlot(m1@Model, "ceq.simple.only") &&
-      m1@Model@ceq.simple.only) {
+    } else if (m1@Model@ceq.simple.only) {
       Delta1 <- Delta1 %*% t(m1@Model@ceq.simple.K)
     }
 
